@@ -372,7 +372,8 @@ def get_last_branch_changeSet(branch, numberOfChangets):
         changeSetDict = {}
         itemsDict = {}
 
-        changeSetDict['branch'] = branch
+        changeSetDict['branch'] = 'branch'
+        changeSetDict['items'] = itemsDict
 
         changeset_info_items = changeset_raw.split("\n\n\n\n")
         changeset_items = list()
@@ -396,10 +397,31 @@ def get_last_branch_changeSet(branch, numberOfChangets):
                 if propertyName == 'items':
                     for i in propertyData.split('\n'):
                         i = i.lstrip().rstrip()
-                        action, filename = i.split(' ', maxsplit=1)
+                        action = i[:i.find("$/")]
+                        filename = i[i.find("$/"):]
+
                         action = action.lstrip().rstrip()
                         filename = filename.lstrip().rstrip()
-                        itemsDict[action] = filename
+
+                        if ',' in action:
+                            actions = action.split(', ')
+                            if all(s in actions for s in ('delete', 'source rename')):
+                                action = 'delete'
+                            elif all(s in actions for s in ('encoding', 'edit')):
+                                action = 'edit'
+                            elif all(s in actions for s in ('merge', 'edit')):
+                                action = 'edit'
+                            elif all(s in actions for s in ('rename', 'edit')):
+                                action = 'rename'
+
+                        if action not in itemsDict:
+                            itemsDict[action] = [filename, ]
+                        else:
+                            itemsDict[action].append(filename)
+
+                    for item in itemsDict:
+                        itemsDict[item] = list(set(itemsDict[item]))
+
                     changeSetDict['items'] = itemsDict
 
         changeSetList.append(changeSetDict)
@@ -500,7 +522,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
     for changeSet in arr:
         files = []
 
-        items = changeSet['items']
+        items = changeSet.get('items', {})
         # print(changeSet)
         changesetId = changeSet.get('changeset')
         if changesetId is None:
@@ -515,8 +537,8 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
         date = changeSet['date']
 
         for key in items:
-            if ';' in key:
-                keys = key.split(";")
+            if ',' in key:
+                keys = key.split(",")
                 if all(s in keys for s in ('delete', 'source rename')):
                     key = 'delete'
                 else:
@@ -533,26 +555,48 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             elif key == "rename":
                 status = "renamed"
 
-            splittedFiles = items[key].split(";")
+            if isinstance(items[key], (list, tuple)):
+                for file_item in items[key]:
+                    splittedFiles = file_item.split(";")
+                    splittedFile = splittedFiles[0]
+                    fileName = splittedFile[splittedFile.rfind("/") + 1:]
 
-            splittedFile = splittedFiles[0]
-            fileName = splittedFile[splittedFile.rfind("/") + 1:]
+                    blame = ''
+                    if isBlameRequired and "." in fileName and status == 'modified':
+                        blame = get_blame(splittedFile, changesetId)
 
-            blame = ''
-            if isBlameRequired and "." in fileName and status == 'modified':
-                blame = get_blame(splittedFile, changesetId)
+                    files.append({
+                        'status': status,
+                        'deletions': 0,
+                        'previous_filename': '',
+                        'patch': '',
+                        'blame': blame,
+                        'sha': changesetId,
+                        'additions': 0,
+                        'filename': file_item,
+                        'changes': 0
+                    })
 
-            files.append({
-                'status': status,
-                'deletions': 0,
-                'previous_filename': '',
-                'patch': '',
-                'blame': blame,
-                'sha': changesetId,
-                'additions': 0,
-                'filename': items[key],
-                'changes': 0
-            })
+            elif isinstance(items[key], str):
+                splittedFiles = items[key].split(";")
+
+                splittedFile = splittedFiles[0]
+                fileName = splittedFile[splittedFile.rfind("/") + 1:]
+
+                blame = ''
+                if isBlameRequired and "." in fileName and status == 'modified':
+                    blame = get_blame(splittedFile, changesetId)
+                files.append({
+                    'status': status,
+                    'deletions': 0,
+                    'previous_filename': '',
+                    'patch': '',
+                    'blame': blame,
+                    'sha': changesetId,
+                    'additions': 0,
+                    'filename': items[key],
+                    'changes': 0
+                })
 
         added = [x for x in files if 'add' in x['status']]
         modified = [x for x in files if 'edit' in x['status']]
